@@ -23,7 +23,7 @@ V1.0.0: Michele Cappellari, Oxford, 08 November 2019
     - Written and tested.
 
 """
-
+import copy
 import numpy as np
 import matplotlib.pyplot as plt
 from scipy import ndimage
@@ -433,19 +433,24 @@ class jam_axi_intr:
 
     beta: array_like with shape (n,)
         Vector with the vertical anisotropy of the individual kinematic-tracer
-        MGE Gaussians (Default: ``beta=np.zeros(N)``)::
+        MGE Gaussians (Default: ``beta=np.zeros(n)``)::
 
             beta = 1 - (sigma_th/sigma_r)^2  # with align=`sph`
             beta = 1 - (sigma_z/sigma_R)^2   # with align=`cyl`
 
     data: array_like of shape (4, p)
-        Four vectors with the observed values of
-        ``[sigR, sigz, sigphi, vphi]`` in km/s.
+        Four input vectors with the observed values of:
+
+        - ``[sigR, sigz, sigphi, vphi]`` in km/s, when ``align='cyl'``
+          (or ``align='sph'`` and ``proj_cyl=True``).
+
+        - ``[sigr, sigth, sigphi, vphi]`` in km/s, when ``align='sph'``.
+
     errors: array_like of shape (4, p)
         errors on ``data``, in the same format (default 5 km/s).
     gamma: array_like with shape (n,)
         Vector with the tangential anisotropy of the individual kinematic-tracer
-        MGE Gaussians (Default: ``gamma=np.zeros(N)``)::
+        MGE Gaussians (Default: ``gamma=np.zeros(n)``)::
 
             gamma = 1 - (sigma_phi/sigma_r)^2  # with align=`sph`
             gamma = 1 - (sigma_phi/sigma_R)^2  # with align=`cyl`
@@ -498,7 +503,7 @@ class jam_axi_intr:
             the second velocity moment in ``(km/s)^2`` along the
             tangential ``phi`` direction at each ``(R, z)`` location.
 
-        The mnean velocity can be computed as ``vphi = np.sqrt(v2phi - sig2phi)``
+        The mean velocity can be computed as ``vphi = np.sqrt(v2phi - sig2phi)``
     .flux: array_like  with shape (p,)
         Vector with the MGE luminosity density at each ``(R, z)`` location in
         ``Lsun/pc^3``, used to plot the isophotes on the model results.
@@ -574,14 +579,14 @@ class jam_axi_intr:
 
         else:
 
-            model1 = model.copy()  # For plotting (sig2r, sig2th, sig2phi, v2phi)
-            model1[3] -= model[2]  # Vphi2 = V2phi - sig2phi
+            model1 = copy.deepcopy(model)   # For plotting (sig2r, sig2th, sig2phi, v2phi)
+            model1[3] -= model[2]           # Vphi2 = V2phi - sig2phi
             model1 = np.sqrt(model1)
             d, m, e, ok = map(np.concatenate, [data, model1, errors, goodbins])
 
             if (ml is None) or (ml <= 0):
-
-                ml = (np.sum(d[ok]*m[ok]/e[ok]**2)/np.sum((m[ok]/e[ok])**2))**2  # eq. (51 C08)
+                # eq. (51) of Cappellari (2008, MNRAS)
+                ml = (np.sum(d[ok]*m[ok]/e[ok]**2)/np.sum((m[ok]/e[ok])**2))**2
                 m *= np.sqrt(ml)
                 model1 = m.reshape(4, -1)
 
@@ -622,60 +627,3 @@ class jam_axi_intr:
                           colorbar=1, label=t)
 
 ##############################################################################
-
-def satoh_solution(R, z, beta):
-
-    G = 0.004301  # (km/s)^2 pc/Msun [6.674e-11 SI units (CODATA-14)]
-    a = b = M = 1
-
-    Q = np.sqrt(b**2 + z**2)
-    S = np.sqrt(a**2 + 2*a*Q + R**2 + z**2)
-    sig2z = G*M*Q*(a + 2*Q)/(3*Q*(a + 2*Q) + S**2)/(2*S)        # eq.(68) Cappellari (2020)
-    v2phi = sig2z*(1 - 6*(R/S)**2)/(1 - beta) + G*M*R**2/S**3   # eq.(69) Cappellari (2020)
-
-    return sig2z, v2phi
-
-##############################################################################
-
-def jam_axi_intr_example():
-    """
-    Usage example for jam_axi_intr()
-    I use as "data" the anysotropic cylindrical solution
-    from Cappellari (2020) for the density by Satoh (1980)
-
-    """
-    rr = np.linspace(0, 16, 32)
-    zz = np.linspace(0, 6, 12)
-    Rbin, zbin = map(np.ravel, np.meshgrid(rr, zz))
-    w = (Rbin == 0) & (zbin == 0)
-    Rbin, zbin = Rbin[~w], zbin[~w]  # Remove central singularity
-    log_dens_lum, log_sigma_lum, qintr_lum = np.loadtxt('python2019/mge_satoh_published.txt', unpack=True)
-    dens_lum, sigma_lum = 10**log_dens_lum, 10**log_sigma_lum
-
-    beta0 = -0.78
-    sig2z, v2phi = satoh_solution(Rbin, zbin, beta0)
-
-    gamma0 = 0.78
-    beta = np.full_like(dens_lum, beta0)
-    gamma = np.full_like(dens_lum, gamma0)
-
-    dens_pot = dens_lum
-    sigma_pot = sigma_lum
-    qintr_pot = qintr_lum
-
-    mbh = 0
-    sig2R = sig2z/(1 - beta0)
-    sig2phi = sig2R*(1- gamma0)
-    data = np.sqrt([sig2R, sig2z, sig2phi, v2phi - sig2phi])
-
-    jam = jam_axi_intr(dens_lum, sigma_lum, qintr_lum, dens_pot, sigma_pot, qintr_pot,
-                        mbh, Rbin, zbin, beta=beta, gamma=gamma, interp=True, align='cyl',
-                        plot=1, data=data, ml=-1)
-
-    print(f"M/L = {jam.ml:.2f}")
-
-##############################################################################
-
-if __name__ == '__main__':
-
-    jam_axi_intr_example()
