@@ -473,7 +473,7 @@ class jam_axi_proj:
         EXAMPLE: In the case where the data are given by the
         ``Vrms = sqrt(velBin^2 + sigBin^2)``, from the error propagation::
 
-            ERMS = sqrt((dVel*velBin)^2 + (dSig*sigBin)^2)/RMS,
+            errors = sqrt((dVel*velBin)^2 + (dSig*sigBin)^2)/RMS,
 
         where ``velBin`` and ``sigBin`` are the velocity and dispersion in each
         bin and ``dVel`` and ``dSig`` are the corresponding uncertainties.
@@ -500,9 +500,9 @@ class jam_axi_proj:
         fraction of the total PSF flux contained in the circular Gaussians
         describing the PSF of the kinematic observations.
         The PSF will be used for seeing convolution of the model kinematics.
-        It has to be ``np.sum(NORMPSF) = 1``.
+        It has to be ``np.sum(normpsf) = 1``.
     nang: int, optional
-        Same as for ``NRAD``, but for the number of angular intervals.
+        Same as for ``nrad``, but for the number of angular intervals.
         (default: ``nang=10``)
     nrad: int, optional
         The number of logarithmically spaced radial positions for which the
